@@ -90,7 +90,7 @@ int get_feat_info_eeprom( updates *node, sensors_chip_name name, int num ) {
 
 #define IT87_NUM_FEAT 15
 
-/* Get the feature info for lm75 sensor. */
+/* Get the feature info for lm87 sensor. */
 int get_feat_info_it87( updates *node, sensors_chip_name name, int num ) {
     switch (num) {
         case 1:
@@ -519,6 +519,91 @@ int get_feat_info_lm80( updates *node, sensors_chip_name name, int num ) {
     return SUCCESS;
 }
 
+#define LM85_NUM_FEAT 12
+
+/* Get the feature info for lm87 sensor. */
+int get_feat_info_lm85( updates *node, sensors_chip_name name, int num ) {
+    switch (num) {
+        case 1:
+            node->featnum = SENSORS_LM85_IN0;
+            node->featminnum = SENSORS_LM85_IN0_MIN;
+            node->featmaxnum = SENSORS_LM85_IN0_MAX;
+            node->feattype = VOLT;
+            break;
+        case 2:
+            node->featnum = SENSORS_LM85_IN1;
+            node->featminnum = SENSORS_LM85_IN1_MIN;
+            node->featmaxnum = SENSORS_LM85_IN1_MAX;
+            node->feattype = VOLT;
+            break;
+        case 3:
+            node->featnum = SENSORS_LM85_IN2;
+            node->featminnum = SENSORS_LM85_IN2_MIN;
+            node->featmaxnum = SENSORS_LM85_IN2_MAX;
+            node->feattype = VOLT;
+            break;
+        case 4:
+            node->featnum = SENSORS_LM85_IN3;
+            node->featminnum = SENSORS_LM85_IN3_MIN;
+            node->featmaxnum = SENSORS_LM85_IN3_MAX;
+            node->feattype = VOLT;
+            break;
+        case 5:
+            node->featnum = SENSORS_LM85_IN4;
+            node->featminnum = SENSORS_LM85_IN4_MIN;
+            node->featmaxnum = SENSORS_LM85_IN4_MAX;
+            node->feattype = VOLT;
+            break;
+        case 6:
+            node->featnum = SENSORS_LM85_FAN1;
+            node->featminnum = SENSORS_LM85_FAN1_MIN;
+            node->featmaxnum = UNDEFMAXMIN;
+            node->feattype = FAN;
+            break;
+        case 7:
+            node->featnum = SENSORS_LM85_FAN2;
+            node->featminnum = SENSORS_LM85_FAN2_MIN;
+            node->featmaxnum = UNDEFMAXMIN;
+            node->feattype = FAN;
+            break;
+        case 8:
+            node->featnum = SENSORS_LM85_FAN3;
+            node->featminnum = SENSORS_LM85_FAN3_MIN;
+            node->featmaxnum = UNDEFMAXMIN;
+            node->feattype = FAN;
+            break;
+        case 9:
+            node->featnum = SENSORS_LM85_FAN4;
+            node->featminnum = SENSORS_LM85_FAN4_MIN;
+            node->featmaxnum = UNDEFMAXMIN;
+            node->feattype = FAN;
+            break;
+        case 10:
+            node->featnum = SENSORS_LM85_TEMP1;
+            node->featminnum = SENSORS_LM85_TEMP1_MIN;
+            node->featmaxnum = SENSORS_LM85_TEMP1_MAX;
+            node->feattype = TEMP;
+            break;
+        case 11:
+            node->featnum = SENSORS_LM85_TEMP2;
+            node->featminnum = SENSORS_LM85_TEMP2_MIN;
+            node->featmaxnum = SENSORS_LM85_TEMP2_MAX;
+            node->feattype = TEMP;
+            break;
+        case 12:
+            node->featnum = SENSORS_LM85_TEMP3;
+            node->featminnum = SENSORS_LM85_TEMP3_MIN;
+            node->featmaxnum = SENSORS_LM85_TEMP3_MAX;
+            node->feattype = TEMP;
+            break;
+        default:
+            return FAILURE;
+            break;
+    }
+
+    return SUCCESS;
+}
+
 #define LM87_NUM_FEAT 13
 
 /* Get the feature info for lm87 sensor. */
@@ -610,6 +695,31 @@ int get_feat_info_lm87( updates *node, sensors_chip_name name, int num ) {
     return SUCCESS;
 }
 
+#define LM90_NUM_FEAT 2
+
+/* Get the feature info for lm90 sensor. */
+int get_feat_info_lm90( updates *node, sensors_chip_name name, int num ) {
+    switch (num) {
+        case 1:
+            node->featnum = SENSORS_LM90_LOCAL_TEMP;
+            node->featminnum = SENSORS_LM90_LOCAL_LOW;
+            node->featmaxnum = SENSORS_LM90_LOCAL_HIGH;
+            node->feattype = TEMP;
+            break;
+        case 2:
+            node->featnum = SENSORS_LM90_REMOTE_TEMP;
+            node->featminnum = SENSORS_LM90_REMOTE_LOW;
+            node->featmaxnum = SENSORS_LM90_REMOTE_HIGH;
+            node->feattype = TEMP;
+            break;
+        default:
+            return FAILURE;
+            break;
+    }
+
+    return SUCCESS;
+}
+
 #define MAX1617_NUM_FEAT 2
 
 /* Get the feature info for max1617 sensor. */
@@ -922,6 +1032,195 @@ int get_feat_info_w83782d( updates *node, sensors_chip_name name, int num ) {
     return SUCCESS;
 }
 
+
+
+
+#define W83783S_NUM_FEAT 12
+                
+/* Get the feature info for w83783s and w83697hf sensor. */
+int get_feat_info_w83783s( updates *node, sensors_chip_name name, int num ) {
+    switch (num) {
+        case 1:
+            node->featnum = SENSORS_W83783S_IN0;
+            node->featminnum = SENSORS_W83783S_IN0_MIN;
+            node->featmaxnum = SENSORS_W83783S_IN0_MAX;
+            node->feattype = VOLT;
+            break;
+        case 2:
+            node->featnum = SENSORS_W83783S_IN1;
+            node->featminnum = SENSORS_W83783S_IN1_MIN;
+            node->featmaxnum = SENSORS_W83783S_IN1_MAX;
+            node->feattype = VOLT;
+            break;
+        case 3:
+            node->featnum = SENSORS_W83783S_IN2;
+            node->featminnum = SENSORS_W83783S_IN2_MIN;
+            node->featmaxnum = SENSORS_W83783S_IN2_MAX;
+            node->feattype = VOLT;
+            break;
+        case 4:
+            node->featnum = SENSORS_W83783S_IN3;
+            node->featminnum = SENSORS_W83783S_IN3_MIN;
+            node->featmaxnum = SENSORS_W83783S_IN3_MAX;
+            node->feattype = VOLT;
+            break;
+        case 5:
+            node->featnum = SENSORS_W83783S_IN4;
+            node->featminnum = SENSORS_W83783S_IN4_MIN;
+            node->featmaxnum = SENSORS_W83783S_IN4_MAX;
+            node->feattype = VOLT;
+            break;
+        case 6:
+            node->featnum = SENSORS_W83783S_IN5;
+            node->featminnum = SENSORS_W83783S_IN5_MIN;
+            node->featmaxnum = SENSORS_W83783S_IN5_MAX;
+            node->feattype = VOLT;
+            break;
+        case 7:
+            node->featnum = SENSORS_W83783S_IN6;
+            node->featminnum = SENSORS_W83783S_IN6_MIN;
+            node->featmaxnum = SENSORS_W83783S_IN6_MAX;
+            node->feattype = VOLT;
+            break;
+        case 8:
+            node->featnum = SENSORS_W83783S_FAN1;
+            node->featminnum = SENSORS_W83783S_FAN1_MIN;
+            node->featmaxnum = UNDEFMAXMIN;
+            node->feattype = FAN;
+            break;
+        case 9:
+            node->featnum = SENSORS_W83783S_FAN2;
+            node->featminnum = SENSORS_W83783S_FAN2_MIN;
+            node->featmaxnum = UNDEFMAXMIN;
+            node->feattype = FAN;
+            break;
+        case 10:
+            node->featnum = SENSORS_W83783S_FAN3;
+            node->featminnum = SENSORS_W83783S_FAN3_MIN;
+            node->featmaxnum = UNDEFMAXMIN;
+            node->feattype = FAN;
+            break;
+        case 11:
+            node->featnum = SENSORS_W83783S_TEMP1;
+            node->featminnum = UNDEFMAXMIN;
+            node->featmaxnum = SENSORS_W83783S_TEMP1_OVER;
+            node->feattype = TEMP;
+            break;
+        case 12:
+            node->featnum = SENSORS_W83783S_TEMP2;
+            node->featminnum = UNDEFMAXMIN;
+            node->featmaxnum = SENSORS_W83783S_TEMP2_OVER;
+            node->feattype = TEMP;
+            break;
+        default:
+            return FAILURE;
+    }
+
+    return SUCCESS;
+}
+
+#define AS99127F_NUM_FEAT 15
+                
+/* Get the feature info for as99127f sensor. */
+int get_feat_info_as99127f( updates *node, sensors_chip_name name, int num ) {
+    switch (num) {
+        case 1:
+            node->featnum = SENSORS_W83782D_IN0;
+            node->featminnum = SENSORS_W83782D_IN0_MIN;
+            node->featmaxnum = SENSORS_W83782D_IN0_MAX;
+            node->feattype = VOLT;
+            break;
+        case 2:
+            node->featnum = SENSORS_W83782D_IN1;
+            node->featminnum = SENSORS_W83782D_IN1_MIN;
+            node->featmaxnum = SENSORS_W83782D_IN1_MAX;
+            node->feattype = VOLT;
+            break;
+        case 3:
+            node->featnum = SENSORS_W83782D_IN2;
+            node->featminnum = SENSORS_W83782D_IN2_MIN;
+            node->featmaxnum = SENSORS_W83782D_IN2_MAX;
+            node->feattype = VOLT;
+            break;
+        case 4:
+            node->featnum = SENSORS_W83782D_IN3;
+            node->featminnum = SENSORS_W83782D_IN3_MIN;
+            node->featmaxnum = SENSORS_W83782D_IN3_MAX;
+            node->feattype = VOLT;
+            break;
+        case 5:
+            node->featnum = SENSORS_W83782D_IN4;
+            node->featminnum = SENSORS_W83782D_IN4_MIN;
+            node->featmaxnum = SENSORS_W83782D_IN4_MAX;
+            node->feattype = VOLT;
+            break;
+        case 6:
+            node->featnum = SENSORS_W83782D_IN5;
+            node->featminnum = SENSORS_W83782D_IN5_MIN;
+            node->featmaxnum = SENSORS_W83782D_IN5_MAX;
+            node->feattype = VOLT;
+            break;
+        case 7:
+            node->featnum = SENSORS_W83782D_IN6;
+            node->featminnum = SENSORS_W83782D_IN6_MIN;
+            node->featmaxnum = SENSORS_W83782D_IN6_MAX;
+            node->feattype = VOLT;
+            break;
+        case 8:
+            node->featnum = SENSORS_W83782D_IN7;
+            node->featminnum = SENSORS_W83782D_IN7_MIN;
+            node->featmaxnum = SENSORS_W83782D_IN7_MAX;
+            node->feattype = VOLT;
+            break;
+        case 9:
+            node->featnum = SENSORS_W83782D_IN8;
+            node->featminnum = SENSORS_W83782D_IN8_MIN;
+            node->featmaxnum = SENSORS_W83782D_IN8_MAX;
+            node->feattype = VOLT;
+            break;
+        case 10:
+            node->featnum = SENSORS_W83782D_FAN1;
+            node->featminnum = SENSORS_W83782D_FAN1_MIN;
+            node->featmaxnum = UNDEFMAXMIN;
+            node->feattype = FAN;
+            break;
+        case 11:
+            node->featnum = SENSORS_W83782D_FAN2;
+            node->featminnum = SENSORS_W83782D_FAN2_MIN;
+            node->featmaxnum = UNDEFMAXMIN;
+            node->feattype = FAN;
+            break;
+        case 12:
+            node->featnum = SENSORS_W83781D_FAN3;
+            node->featminnum = SENSORS_W83781D_FAN3_MIN;
+            node->featmaxnum = UNDEFMAXMIN;
+            node->feattype = FAN;
+            break;
+        case 13:
+            node->featnum = SENSORS_W83782D_TEMP1;
+            node->featminnum = UNDEFMAXMIN;
+            node->featmaxnum = SENSORS_W83782D_TEMP1_OVER;
+            node->feattype = TEMP;
+            break;
+        case 14:
+            node->featnum = SENSORS_W83781D_TEMP2;
+            node->featminnum = UNDEFMAXMIN;
+            node->featmaxnum = SENSORS_W83782D_TEMP2_OVER;
+            node->feattype = TEMP;
+            break;
+        case 15:
+            node->featnum = SENSORS_W83782D_TEMP3;
+            node->featminnum = UNDEFMAXMIN;
+            node->featmaxnum = SENSORS_W83782D_TEMP3_OVER;
+            node->feattype = TEMP;
+            break;
+        default:
+            return FAILURE;
+    }
+
+    return SUCCESS;
+}
+
 /* Simply return the number of features a specified sensor has from
  * defines above.
  */
@@ -946,18 +1245,37 @@ int get_num_feat( sensors_chip_name name ) {
         return LM79_NUM_FEAT;
     } else if ( strcmp( name.prefix, SENSORS_LM80_PREFIX ) == 0 ) {
         return LM80_NUM_FEAT;
+    } else if ( ( strcmp( name.prefix, SENSORS_LM85_PREFIX ) == 0 ) ||
+                ( strcmp( name.prefix, SENSORS_LM85B_PREFIX ) == 0 ) ||
+                ( strcmp( name.prefix, SENSORS_LM85C_PREFIX ) == 0 ) ||
+                ( strcmp( name.prefix, SENSORS_ADM1027_PREFIX ) == 0 ) ||
+                ( strcmp( name.prefix, SENSORS_ADT7463_PREFIX ) == 0 ) ||
+                ( strcmp( name.prefix, SENSORS_EMC6D100_PREFIX ) == 0 ) ) {
+        return LM85_NUM_FEAT;
     } else if ( strcmp( name.prefix, SENSORS_LM87_PREFIX ) == 0 ) {
         return LM87_NUM_FEAT;
-    } else if ( strcmp( name.prefix, SENSORS_MAX1617_PREFIX ) == 0 ) {
+    } else if ( ( strcmp( name.prefix, SENSORS_LM90_PREFIX ) == 0 ) ||
+                ( strcmp( name.prefix, SENSORS_ADM1032_PREFIX ) == 0 ) ) {
+        return LM90_NUM_FEAT;
+    } else if ( ( strcmp( name.prefix, SENSORS_MAX1617_PREFIX ) == 0 ) ||
+    		( strcmp( name.prefix, SENSORS_MC1066_PREFIX ) == 0 ) ) {
         return MAX1617_NUM_FEAT;
+    } else if ( strcmp( name.prefix, SENSORS_MAX1617A_PREFIX ) == 0 ) {
+        return MAX1617A_NUM_FEAT;
     } else if ( strcmp( name.prefix, SENSORS_VIA686A_PREFIX ) == 0 ) {
         return VIA686A_NUM_FEAT;
     } else if ( strcmp( name.prefix, SENSORS_W83781D_PREFIX ) == 0 ) {
         return W83781D_NUM_FEAT;
     } else if ( ( strcmp( name.prefix, SENSORS_W83782D_PREFIX ) == 0 ) ||
                 ( strcmp( name.prefix, SENSORS_W83627HF_PREFIX ) == 0 ) ||
-                ( strcmp( name.prefix, SENSORS_AS99127F_PREFIX ) == 0 ) ) {
+                ( strcmp( name.prefix, SENSORS_W83627THF_PREFIX ) == 0 ) ||
+                ( strcmp( name.prefix, SENSORS_W83791D_PREFIX ) == 0 ) ) {
         return W83782D_NUM_FEAT;
+    } else if ( ( strcmp( name.prefix, SENSORS_W83783S_PREFIX ) == 0 ) ||
+                ( strcmp( name.prefix, SENSORS_W83697HF_PREFIX ) == 0 ) ) {
+        return W83783S_NUM_FEAT;
+    } else if ( strcmp( name.prefix, SENSORS_AS99127F_PREFIX ) == 0 ) {
+        return AS99127F_NUM_FEAT;
     } else {
         return 0;
     }
@@ -993,9 +1311,20 @@ updates *add_node( updates *node, sensors_chip_name name, GtkWidget *darea,
         retval = get_feat_info_lm79( node, name, num );
     } else if ( strcmp( name.prefix, SENSORS_LM80_PREFIX ) == 0 ) {
         retval = get_feat_info_lm80( node, name, num );
+    } else if ( ( strcmp( name.prefix, SENSORS_LM85_PREFIX ) == 0 ) ||
+                ( strcmp( name.prefix, SENSORS_LM85B_PREFIX ) == 0 ) ||
+                ( strcmp( name.prefix, SENSORS_LM85C_PREFIX ) == 0 ) ||
+                ( strcmp( name.prefix, SENSORS_ADM1027_PREFIX ) == 0 ) ||
+                ( strcmp( name.prefix, SENSORS_ADT7463_PREFIX ) == 0 ) ||
+                ( strcmp( name.prefix, SENSORS_EMC6D100_PREFIX ) == 0 ) ) {
+        retval = get_feat_info_lm85( node, name, num );
     } else if ( strcmp( name.prefix, SENSORS_LM87_PREFIX ) == 0 ) {
         retval = get_feat_info_lm87( node, name, num );
-    } else if ( strcmp( name.prefix, SENSORS_MAX1617_PREFIX ) == 0 ) {
+    } else if ( ( strcmp( name.prefix, SENSORS_LM90_PREFIX ) == 0 ) ||
+                ( strcmp( name.prefix, SENSORS_ADM1032_PREFIX ) == 0 ) ) {
+        retval = get_feat_info_lm90( node, name, num );
+    } else if ( ( strcmp( name.prefix, SENSORS_MAX1617_PREFIX ) == 0 ) ||
+                ( strcmp( name.prefix, SENSORS_MC1066_PREFIX ) == 0 ) ) {
         retval = get_feat_info_max1617( node, name, num );
     } else if ( strcmp( name.prefix, SENSORS_MAX1617A_PREFIX ) == 0 ) {
         retval = get_feat_info_max1617a( node, name, num );
@@ -1005,8 +1334,14 @@ updates *add_node( updates *node, sensors_chip_name name, GtkWidget *darea,
         retval = get_feat_info_w83781d( node, name, num );
     } else if ( ( strcmp( name.prefix, SENSORS_W83782D_PREFIX ) == 0 ) ||
                 ( strcmp( name.prefix, SENSORS_W83627HF_PREFIX ) == 0 ) ||
-                ( strcmp( name.prefix, SENSORS_AS99127F_PREFIX ) == 0 ) ) {
+                ( strcmp( name.prefix, SENSORS_W83627THF_PREFIX ) == 0 ) ||
+                ( strcmp( name.prefix, SENSORS_W83791D_PREFIX ) == 0 ) ) {
         retval = get_feat_info_w83782d( node, name, num );
+    } else if ( ( strcmp( name.prefix, SENSORS_W83783S_PREFIX ) == 0 ) ||
+                ( strcmp( name.prefix, SENSORS_W83697HF_PREFIX ) == 0 ) ) {
+        retval = get_feat_info_w83783s( node, name, num );
+    } else if ( strcmp( name.prefix, SENSORS_AS99127F_PREFIX ) == 0 ) {
+        retval = get_feat_info_as99127f( node, name, num );
     } else {
         g_free( node );
         return NULL;
