@@ -21,10 +21,13 @@
 #include "main.h"
 
 extern int tf;
+extern int update_time;
 extern char *imagefile;
 
 GtkWidget *mainwindow = NULL;
 
+GdkColor colorWhite = { 0, 0xFFFF, 0xFFFF, 0xFFFF };
+    
 GdkColormap *cmap = NULL;
 
 GdkPixmap *theme = NULL;
@@ -56,6 +59,7 @@ gint destroy_gui( GtkWidget *widget, gpointer data ) {
 
     return (FALSE);
 }
+
 void get_pm_location( int curInt, int *x ) {
     switch ( curInt ) {
         case 0:
@@ -92,6 +96,7 @@ void get_pm_location( int curInt, int *x ) {
             break;
     }
 }
+
 /* Expose event function to draw graphical numbers. */
 gboolean expose_event_callback( GtkWidget *widget, GdkEventExpose *event, 
                                 gpointer data) {
@@ -106,7 +111,7 @@ gboolean expose_event_callback( GtkWidget *widget, GdkEventExpose *event,
 
     double a, b, c, d, tempD;
 
-#ifdef DEBUG
+#ifdef DEBUG_XSENSORS
     printf( "area.width = %d, area.height = %d\n", event->area.width,
             event->area.height );
 #endif
@@ -122,58 +127,61 @@ gboolean expose_event_callback( GtkWidget *widget, GdkEventExpose *event,
             result = (int) current->curvalue;
             
             x = 198;
-            gdk_draw_pixmap( widget->window, 
-                             widget->style->fg_gc[ GTK_WIDGET_STATE 
-                             (widget) ], theme, x, highLow, 
-                             0, 0, 18, 30 );
+            gdk_draw_drawable( widget->window, 
+                               widget->style->fg_gc[ GTK_WIDGET_STATE 
+                               (widget) ], theme, x, highLow, 
+                               0, 0, 18, 30 );
            
             curInt = result / 1000;
             result = result % 1000;
             
             get_pm_location( curInt, &x );
-            gdk_draw_pixmap( widget->window, 
-                             widget->style->fg_gc[ GTK_WIDGET_STATE 
-                             (widget) ], theme, x, highLow, 
-                             18, 0, 18, 30 );
+            gdk_draw_drawable( widget->window, 
+                               widget->style->fg_gc[ GTK_WIDGET_STATE 
+                               (widget) ], theme, x, highLow, 
+                               18, 0, 18, 30 );
 
             curInt = result / 100;
             result = result % 100;
             
             get_pm_location( curInt, &x );
-            gdk_draw_pixmap( widget->window, 
-                             widget->style->fg_gc[ GTK_WIDGET_STATE 
-                             (widget) ], theme, x, highLow, 
-                             36, 0, 18, 30 );
+            gdk_draw_drawable( widget->window, 
+                               widget->style->fg_gc[ GTK_WIDGET_STATE 
+                               (widget) ], theme, x, highLow, 
+                               36, 0, 18, 30 );
 
             curInt = result / 10;
             result = result % 10;
             
             get_pm_location( curInt, &x );
-            gdk_draw_pixmap( widget->window, 
-                             widget->style->fg_gc[ GTK_WIDGET_STATE 
-                             (widget) ], theme, x, highLow, 
-                             54, 0, 18, 30 );
+            gdk_draw_drawable( widget->window, 
+                               widget->style->fg_gc[ GTK_WIDGET_STATE 
+                               (widget) ], theme, x, highLow, 
+                               54, 0, 18, 30 );
 
             curInt = result;
             
             get_pm_location( curInt, &x );
-            gdk_draw_pixmap( widget->window, 
-                             widget->style->fg_gc[ GTK_WIDGET_STATE 
-                             (widget) ], theme, x, highLow, 
-                             72, 0, 18, 30 );
+            gdk_draw_drawable( widget->window, 
+                               widget->style->fg_gc[ GTK_WIDGET_STATE 
+                               (widget) ], theme, x, highLow, 
+                               72, 0, 18, 30 );
 
-            gdk_draw_pixmap( widget->window, 
-                             widget->style->fg_gc[ GTK_WIDGET_STATE 
-                             (widget) ], theme, 0, 120 + highLow, 
-                             90, 0, 57, 30 );
+            gdk_draw_drawable( widget->window, 
+                               widget->style->fg_gc[ GTK_WIDGET_STATE 
+                               (widget) ], theme, 0, 120 + highLow, 
+                               90, 0, 57, 30 );
             break;
         case TEMP:
             if ( current->curvalue > current->curmax )
                 highLow = 30;
 
+            if ( tf == TRUE )
+                current->curvalue = ( 1.8 * current->curvalue ) + 32;
+
             result = (int) ( current->curvalue * 10 );
             
-            gdk_draw_pixmap( widget->window, 
+            gdk_draw_drawable( widget->window, 
                              widget->style->fg_gc[ GTK_WIDGET_STATE 
                              (widget) ], theme, 198, highLow, 
                              0, 0, 18, 30 );
@@ -185,7 +193,7 @@ gboolean expose_event_callback( GtkWidget *widget, GdkEventExpose *event,
             } else {
                 x = 198;
             }
-            gdk_draw_pixmap( widget->window, 
+            gdk_draw_drawable( widget->window, 
                              widget->style->fg_gc[ GTK_WIDGET_STATE 
                              (widget) ], theme, x, highLow, 
                              18, 0, 18, 30 );
@@ -194,7 +202,7 @@ gboolean expose_event_callback( GtkWidget *widget, GdkEventExpose *event,
             result = result % 100;
 
             get_pm_location( curInt, &x );
-            gdk_draw_pixmap( widget->window, 
+            gdk_draw_drawable( widget->window, 
                              widget->style->fg_gc[ GTK_WIDGET_STATE 
                              (widget) ], theme, x, highLow, 
                              36, 0, 18, 30 );
@@ -203,19 +211,19 @@ gboolean expose_event_callback( GtkWidget *widget, GdkEventExpose *event,
             result = result % 10;
 
             get_pm_location( curInt, &x );
-            gdk_draw_pixmap( widget->window, 
+            gdk_draw_drawable( widget->window, 
                              widget->style->fg_gc[ GTK_WIDGET_STATE 
                              (widget) ], theme, x, highLow, 
                              54, 0, 18, 30 );
             
-            gdk_draw_pixmap( widget->window, 
+            gdk_draw_drawable( widget->window, 
                              widget->style->fg_gc[ GTK_WIDGET_STATE 
                              (widget) ], theme, 171, 60 + highLow, 
                              72, 0, 18, 30 );
 
             curInt = result;
             get_pm_location( curInt, &x );
-            gdk_draw_pixmap( widget->window, 
+            gdk_draw_drawable( widget->window, 
                              widget->style->fg_gc[ GTK_WIDGET_STATE 
                              (widget) ], theme, x, highLow, 
                              78, 0, 18, 30 );
@@ -224,7 +232,7 @@ gboolean expose_event_callback( GtkWidget *widget, GdkEventExpose *event,
                 x = 0;
             else
                 x = 57;
-            gdk_draw_pixmap( widget->window, 
+            gdk_draw_drawable( widget->window, 
                              widget->style->fg_gc[ GTK_WIDGET_STATE 
                              (widget) ], theme, x, 60 + highLow, 
                              96, 0, 57, 30 );
@@ -244,7 +252,7 @@ gboolean expose_event_callback( GtkWidget *widget, GdkEventExpose *event,
                 x = 198;
             }
 
-            gdk_draw_pixmap( widget->window,
+            gdk_draw_drawable( widget->window,
                              widget->style->fg_gc[ GTK_WIDGET_STATE
                              (widget) ], theme, x, highLow, 
                              0, 0, 18, 30 );
@@ -256,7 +264,7 @@ gboolean expose_event_callback( GtkWidget *widget, GdkEventExpose *event,
             } else {
                 x = 198;
             }
-            gdk_draw_pixmap( widget->window, 
+            gdk_draw_drawable( widget->window, 
                              widget->style->fg_gc[ GTK_WIDGET_STATE 
                              (widget) ], theme, x, highLow, 
                              18, 0, 18, 30 );
@@ -265,13 +273,13 @@ gboolean expose_event_callback( GtkWidget *widget, GdkEventExpose *event,
             result = result % 100;
 
             get_pm_location( curInt, &x );
-            gdk_draw_pixmap( widget->window, 
+            gdk_draw_drawable( widget->window, 
                              widget->style->fg_gc[ GTK_WIDGET_STATE 
                              (widget) ], theme, x, highLow, 
                              36, 0, 18, 30 );
 
             /* Display decimal point */
-            gdk_draw_pixmap( widget->window, 
+            gdk_draw_drawable( widget->window, 
                              widget->style->fg_gc[ GTK_WIDGET_STATE 
                              (widget) ], theme, 171, 60 + highLow, 
                              54, 0, 6, 30 );
@@ -280,7 +288,7 @@ gboolean expose_event_callback( GtkWidget *widget, GdkEventExpose *event,
             result = result % 10;
 
             get_pm_location( curInt, &x );
-            gdk_draw_pixmap( widget->window, 
+            gdk_draw_drawable( widget->window, 
                              widget->style->fg_gc[ GTK_WIDGET_STATE 
                              (widget) ], theme, x, highLow, 
                              60, 0, 18, 30 );
@@ -288,13 +296,13 @@ gboolean expose_event_callback( GtkWidget *widget, GdkEventExpose *event,
 
             curInt = result;
             get_pm_location( curInt, &x );
-            gdk_draw_pixmap( widget->window, 
+            gdk_draw_drawable( widget->window, 
                              widget->style->fg_gc[ GTK_WIDGET_STATE 
                              (widget) ], theme, x, highLow, 
                              78, 0, 18, 30 );
 
             /* Display V */
-            gdk_draw_pixmap( widget->window, 
+            gdk_draw_drawable( widget->window, 
                              widget->style->fg_gc[ GTK_WIDGET_STATE 
                              (widget) ], theme, 114, 60 + highLow, 
                              96, 0, 57, 30 );
@@ -307,35 +315,35 @@ gboolean expose_event_callback( GtkWidget *widget, GdkEventExpose *event,
             /* Special case for know EEPROM types. */
             if ( current->featnum == SENSORS_EEPROM_TYPE ) {
                 if ( current->curvalue == 4 ) {
-                    gdk_draw_pixmap( widget->window,
+                    gdk_draw_drawable( widget->window,
                                      widget->style->fg_gc[ GTK_WIDGET_STATE
                                      (widget) ], theme, 118, 120,
                                      0, 0, 98, 30 );
-                    gdk_draw_pixmap( widget->window,
+                    gdk_draw_drawable( widget->window,
                                      widget->style->fg_gc[ GTK_WIDGET_STATE
                                      (widget) ], theme, 54, 150,
                                      98, 0, 75, 30 );
                 } else if ( current->curvalue == 7 ) {
-                    gdk_draw_pixmap( widget->window,
+                    gdk_draw_drawable( widget->window,
                                      widget->style->fg_gc[ GTK_WIDGET_STATE
                                      (widget) ], theme, 55, 120,
                                      0, 0, 161, 30 );
-                    gdk_draw_pixmap( widget->window,
+                    gdk_draw_drawable( widget->window,
                                      widget->style->fg_gc[ GTK_WIDGET_STATE
                                      (widget) ], theme, 54, 150,
                                      161, 0, 75, 30 );
                 } else {
-                    gdk_draw_pixmap( widget->window, 
+                    gdk_draw_drawable( widget->window, 
                                      widget->style->fg_gc[ GTK_WIDGET_STATE 
                                      (widget) ], theme, 198, highLow, 
                                      18, 0, 18, 30 );
                 
-                    gdk_draw_pixmap( widget->window, 
+                    gdk_draw_drawable( widget->window, 
                                      widget->style->fg_gc[ GTK_WIDGET_STATE 
                                      (widget) ], theme, 198, highLow, 
                                      36, 0, 18, 30 );
                 
-                    gdk_draw_pixmap( widget->window, 
+                    gdk_draw_drawable( widget->window, 
                                      widget->style->fg_gc[ GTK_WIDGET_STATE 
                                      (widget) ], theme, 198, highLow, 
                                      54, 0, 18, 30 );
@@ -349,7 +357,7 @@ gboolean expose_event_callback( GtkWidget *widget, GdkEventExpose *event,
                         x = 198;
                     }
             
-                    gdk_draw_pixmap( widget->window, 
+                    gdk_draw_drawable( widget->window, 
                                      widget->style->fg_gc[ GTK_WIDGET_STATE 
                                      (widget) ], theme, x, highLow, 
                                      72, 0, 18, 30 );
@@ -363,7 +371,7 @@ gboolean expose_event_callback( GtkWidget *widget, GdkEventExpose *event,
                         x = 198;
                     }
             
-                    gdk_draw_pixmap( widget->window, 
+                    gdk_draw_drawable( widget->window, 
                                      widget->style->fg_gc[ GTK_WIDGET_STATE 
                                      (widget) ], theme, x, highLow, 
                                      90, 0, 18, 30 );
@@ -371,22 +379,22 @@ gboolean expose_event_callback( GtkWidget *widget, GdkEventExpose *event,
                     curInt = result;
             
                     get_pm_location( curInt, &x );
-                    gdk_draw_pixmap( widget->window, 
+                    gdk_draw_drawable( widget->window, 
                                      widget->style->fg_gc[ GTK_WIDGET_STATE 
                                      (widget) ], theme, x, highLow, 
                                      108, 0, 18, 30 );
 
-                    gdk_draw_pixmap( widget->window, 
+                    gdk_draw_drawable( widget->window, 
                                      widget->style->fg_gc[ GTK_WIDGET_STATE 
                                      (widget) ], theme, 198, highLow, 
                                      126, 0, 18, 30 );
                 
-                    gdk_draw_pixmap( widget->window, 
+                    gdk_draw_drawable( widget->window, 
                                      widget->style->fg_gc[ GTK_WIDGET_STATE 
                                      (widget) ], theme, 198, highLow, 
                                      144, 0, 18, 30 );
                 
-                    gdk_draw_pixmap( widget->window, 
+                    gdk_draw_drawable( widget->window, 
                                      widget->style->fg_gc[ GTK_WIDGET_STATE 
                                      (widget) ], theme, 198, highLow, 
                                      162, 0, 18, 30 );
@@ -410,12 +418,12 @@ gboolean expose_event_callback( GtkWidget *widget, GdkEventExpose *event,
                         result = (1 << result) * ((int) c) * ((int) d);
                 }
            
-                gdk_draw_pixmap( widget->window, 
+                gdk_draw_drawable( widget->window, 
                                  widget->style->fg_gc[ GTK_WIDGET_STATE 
                                  (widget) ], theme, 198, highLow, 
                                  18, 0, 18, 30 );
                 
-                gdk_draw_pixmap( widget->window, 
+                gdk_draw_drawable( widget->window, 
                                  widget->style->fg_gc[ GTK_WIDGET_STATE 
                                  (widget) ], theme, 198, highLow, 
                                  36, 0, 18, 30 );
@@ -429,7 +437,7 @@ gboolean expose_event_callback( GtkWidget *widget, GdkEventExpose *event,
                     x = 198;
                 }
                    
-                gdk_draw_pixmap( widget->window, 
+                gdk_draw_drawable( widget->window, 
                                  widget->style->fg_gc[ GTK_WIDGET_STATE 
                                  (widget) ], theme, x, highLow, 
                                  54, 0, 18, 30 );
@@ -443,7 +451,7 @@ gboolean expose_event_callback( GtkWidget *widget, GdkEventExpose *event,
                     x = 198;
                 }
             
-                gdk_draw_pixmap( widget->window, 
+                gdk_draw_drawable( widget->window, 
                                  widget->style->fg_gc[ GTK_WIDGET_STATE 
                                  (widget) ], theme, x, highLow, 
                                  72, 0, 18, 30 );
@@ -457,7 +465,7 @@ gboolean expose_event_callback( GtkWidget *widget, GdkEventExpose *event,
                     x = 198;
                 }
             
-                gdk_draw_pixmap( widget->window, 
+                gdk_draw_drawable( widget->window, 
                                  widget->style->fg_gc[ GTK_WIDGET_STATE 
                                  (widget) ], theme, x, highLow, 
                                  90, 0, 18, 30 );
@@ -465,22 +473,22 @@ gboolean expose_event_callback( GtkWidget *widget, GdkEventExpose *event,
                 curInt = result;
             
                 get_pm_location( curInt, &x );
-                gdk_draw_pixmap( widget->window, 
+                gdk_draw_drawable( widget->window, 
                                  widget->style->fg_gc[ GTK_WIDGET_STATE 
                                  (widget) ], theme, x, highLow, 
                                  108, 0, 18, 30 );
 
-                gdk_draw_pixmap( widget->window, 
+                gdk_draw_drawable( widget->window, 
                                  widget->style->fg_gc[ GTK_WIDGET_STATE 
                                  (widget) ], theme, 198, highLow, 
                                  126, 0, 18, 30 );
                     
-                gdk_draw_pixmap( widget->window, 
+                gdk_draw_drawable( widget->window, 
                                  widget->style->fg_gc[ GTK_WIDGET_STATE 
                                  (widget) ], theme, 198, highLow, 
                                  144, 0, 18, 30 );
                     
-                gdk_draw_pixmap( widget->window, 
+                gdk_draw_drawable( widget->window, 
                                  widget->style->fg_gc[ GTK_WIDGET_STATE 
                                  (widget) ], theme, 198, highLow, 
                                  162, 0, 18, 30 );
@@ -492,8 +500,6 @@ gboolean expose_event_callback( GtkWidget *widget, GdkEventExpose *event,
             break;
     }
             
-    /* gdk_gc_set_clip_rectangle (widget->style->fg_gc[widget->state], NULL); */
-
     return TRUE;
 }
 
@@ -544,7 +550,7 @@ gint update_sensor_data( gpointer data ) {
             } else {
                 percent = 0.0;
             }
-#ifdef DEBUG
+#ifdef DEBUG_XSENSORS
             printf( "curvalue = %f, curmax = %f, curmin = %f, percent = %f\n", 
                     updata->curvalue, updata->curmax, updata->curmin, percent );
 #endif
@@ -555,7 +561,8 @@ gint update_sensor_data( gpointer data ) {
             if ( percent > 1 )
                 percent = 1;
 
-            gtk_progress_set_percentage( GTK_PROGRESS (updata->pbar), percent );
+            gtk_progress_bar_set_fraction( GTK_PROGRESS_BAR (updata->pbar), 
+                                           percent );
         }
 
         gtk_widget_queue_draw_area( updata->darea, 0, 0, 153, 30 );
@@ -564,7 +571,7 @@ gint update_sensor_data( gpointer data ) {
 
     } while ( updata != NULL );
 
-#ifdef DEBUG
+#ifdef DEBUG_XSENSORS
     printf( "\n" );
 #endif
 
@@ -576,8 +583,9 @@ gint start_timer( GtkWidget *widget, gpointer data ) {
     gint timer;
 
     /* Setup timer for updates. */
-    timer = gtk_timeout_add( 1000, (GtkFunction) update_sensor_data, 
-            (gpointer) data );
+    timer = g_timeout_add( update_time * 1000, 
+                             (GtkFunction) update_sensor_data, 
+			     (gpointer) data );
 
     return SUCCESS;
 }
@@ -590,6 +598,7 @@ updates *add_sensor_tab( GtkWidget *container, sensors_chip_name name ) {
     GtkWidget *fanbox = NULL;
     GtkWidget *eeprombox = NULL;
     GtkWidget *currbox = NULL;
+    GtkWidget *innerbox = NULL;
    
     /* notebook stuff */
     GtkWidget *notelabel = NULL;
@@ -615,13 +624,13 @@ updates *add_sensor_tab( GtkWidget *container, sensors_chip_name name ) {
    
     /* fields placed in the notebook to display feature info */
     GtkWidget *darea = NULL;
-    GtkWidget *featlabel = NULL;
     char *feattext = NULL;
+    GtkWidget *featframe = NULL;
     GtkWidget *featpbar = NULL;
  
     /* Setup main boxes. */
     mainbox = gtk_hbox_new( TRUE, 10 );
-    gtk_container_border_width( GTK_CONTAINER (mainbox), 10 );
+    gtk_container_set_border_width( GTK_CONTAINER (mainbox), 10 );
     gtk_widget_show( mainbox );
     voltbox = gtk_vbox_new( FALSE, 0 );
     tempbox = gtk_vbox_new( FALSE, 0 );
@@ -652,9 +661,12 @@ updates *add_sensor_tab( GtkWidget *container, sensors_chip_name name ) {
     /* Create labels and entry fields for features. */
     numfeat = get_num_feat( name );
     for ( i = 1; i <= numfeat; i++ ) {
+            featframe = gtk_frame_new( NULL );
+            innerbox = gtk_vbox_new( FALSE, 0 );
             featpbar = gtk_progress_bar_new();
             darea = gtk_drawing_area_new();
-            gtk_drawing_area_size( GTK_DRAWING_AREA (darea), 36, 30 );
+            gtk_widget_modify_bg( darea, GTK_STATE_NORMAL, &colorWhite );
+            gtk_widget_set_size_request( darea, 36, 30 );
             
             if ( head == NULL ) {
                 prev = head;
@@ -666,7 +678,7 @@ updates *add_sensor_tab( GtkWidget *container, sensors_chip_name name ) {
             }
 
             if ( current->featnum == SENSORS_EEPROM_TYPE )
-                gtk_drawing_area_size( GTK_DRAWING_AREA (darea), 236, 30 );
+                gtk_widget_set_size_request( darea, 236, 30 );
 
             if ( sensors_get_ignored( current->name, current->featnum ) == 0 ) {
                 prev->next = current->next;
@@ -676,13 +688,12 @@ updates *add_sensor_tab( GtkWidget *container, sensors_chip_name name ) {
             }
 
             /* Connect the expose event sinal handler to redraw the numbers. */
-            gtk_signal_connect( GTK_OBJECT (darea), "expose_event", 
-                                GTK_SIGNAL_FUNC (expose_event_callback), 
-                                current );
+            g_signal_connect( G_OBJECT(darea), "expose_event", 
+                              G_CALLBACK(expose_event_callback), current );
             
             sensors_get_label( name, current->featnum, &feattext );
             if ( feattext != NULL ) {
-#ifdef DEBUG
+#ifdef DEBUG_XSENSORS
                 printf( "Adding feature %d, %s.\n", i, feattext );
 #endif
                 if ( ( feattext = realloc( feattext, 
@@ -695,7 +706,9 @@ updates *add_sensor_tab( GtkWidget *container, sensors_chip_name name ) {
                     fprintf( stderr, "strcat failed in add_sensor_tab()!\n" );
                     return NULL;
                 }
-                featlabel = gtk_label_new( feattext );
+                
+                gtk_frame_set_label( GTK_FRAME (featframe), feattext );
+
                 switch ( current->feattype ) {
                     case VOLT:
                         currbox = voltbox;
@@ -718,19 +731,21 @@ updates *add_sensor_tab( GtkWidget *container, sensors_chip_name name ) {
                                  "Type not recognized, not packing.\n" );
                         break;
                 }
-                gtk_box_pack_start( GTK_BOX (currbox), featlabel, 
+                gtk_box_pack_start( GTK_BOX (currbox), featframe, 
                                     FALSE, FALSE, 0 );
-                gtk_box_pack_start( GTK_BOX (currbox), darea, 
+                gtk_container_add (GTK_CONTAINER (featframe), innerbox);
+                gtk_box_pack_start( GTK_BOX (innerbox), darea, 
                                     FALSE, FALSE, 0 );
                 
                 if ( current->feattype != EEPROM )
-                    gtk_box_pack_start( GTK_BOX (currbox), featpbar, 
+                    gtk_box_pack_start( GTK_BOX (innerbox), featpbar, 
                                         FALSE, FALSE, 0 );
 
             } else {
-                featlabel = gtk_label_new( NA );
+                gtk_frame_set_label( GTK_FRAME (featframe), feattext );
             }
-            gtk_widget_show( featlabel );
+            gtk_widget_show( featframe );
+            gtk_widget_show( innerbox );
             gtk_widget_show( darea );
             if ( current->feattype != EEPROM )
                 gtk_widget_show( featpbar );
@@ -769,8 +784,9 @@ updates *add_sensor_tab( GtkWidget *container, sensors_chip_name name ) {
 
 int start_gui( int argc, char **argv ) {
     struct stat sbuf;
+    char *title = NULL;
     int errone;
-    
+
     GtkWidget *notebook = NULL;
     
     updates *head = NULL;
@@ -780,12 +796,19 @@ int start_gui( int argc, char **argv ) {
 
     gtk_init( &argc, &argv );
 
+    if ( ( title = g_malloc( 15 * sizeof( char ) ) ) == NULL ) {
+            fprintf( stderr, "malloc failed!\n" );
+            exit( 1 );
+    }
+
     /* Setup main window. */
     mainwindow = gtk_window_new( GTK_WINDOW_TOPLEVEL );
-    gtk_window_set_title( GTK_WINDOW (mainwindow), "xsensors" );
-    gtk_signal_connect( GTK_OBJECT (mainwindow), "delete_event",
-            GTK_SIGNAL_FUNC (destroy_gui), NULL );
-    
+    title = strcpy( title, "xsensors " ); 
+    title = strcat( title, VERSION );
+    gtk_window_set_title( GTK_WINDOW (mainwindow), title );
+    g_signal_connect( G_OBJECT (mainwindow), "delete_event",
+                      G_CALLBACK (destroy_gui), NULL );
+
     /* Graphics needed for drawing info. */
     cmap = gtk_widget_get_colormap( mainwindow );
 
@@ -828,6 +851,7 @@ int start_gui( int argc, char **argv ) {
     
     /* Create notebook for sensors. */
     notebook = gtk_notebook_new( );
+    gtk_widget_modify_bg( notebook, GTK_STATE_NORMAL, &colorWhite );
     gtk_notebook_set_tab_pos( GTK_NOTEBOOK (notebook), GTK_POS_LEFT );
     gtk_widget_show( notebook );
 
@@ -835,15 +859,15 @@ int start_gui( int argc, char **argv ) {
 
     while ( ( name = sensors_get_detected_chips( &chipnum ) ) != NULL ) {
         if ( get_num_feat( *name ) > 0 ) {
-#ifdef DEBUG
+#ifdef DEBUG_XSENSORS
             printf( "Adding tab for %s\n", name->prefix );
 #endif
             if ( ( head = add_sensor_tab( notebook, *name ) ) == NULL )
                 return FAILURE;
             
             update_sensor_data( head );
-            gtk_signal_connect( GTK_OBJECT (mainwindow), "realize",
-                    GTK_SIGNAL_FUNC (start_timer), head );
+            g_signal_connect( G_OBJECT (mainwindow), "realize",
+                              G_CALLBACK (start_timer), head );
         } else {
             fprintf( stderr, "Sensor '%s' not supported by xsensors!\n", 
                      name->prefix );
@@ -856,6 +880,7 @@ int start_gui( int argc, char **argv ) {
     gtk_main();
 
     free_llist( head );
+    free( title );
 
     return SUCCESS;
 }
